Add VG_ prefix to SKIPLIST_INIT and IS_*_ALIGNED macros.  Also pull
IS_PAGE_ALIGNED into tool.h with the others.



git-svn-id: svn://svn.valgrind.org/valgrind/trunk@3457 a5019735-40e9-0310-863c-91ae7b9d1cf9
diff --git a/coregrind/vg_redir.c b/coregrind/vg_redir.c
index 5461202..8e296e1 100644
--- a/coregrind/vg_redir.c
+++ b/coregrind/vg_redir.c
@@ -81,7 +81,7 @@
    return buf;
 }
 
-static SkipList sk_resolved_redir = SKIPLIST_INIT(CodeRedirect, from_addr, 
+static SkipList sk_resolved_redir = VG_SKIPLIST_INIT(CodeRedirect, from_addr, 
 						  VG_(cmp_Addr), straddr, VG_AR_SYMTAB);
 static CodeRedirect *unresolved_redir = NULL;
 
@@ -518,7 +518,7 @@
 //:: }
 //:: 
 //:: /* List of wrapped call invocations which are currently active */
 //:: static SkipList wrapped_frames = SKIPLIST_INIT(struct call_instance, key, keycmp, 
 //:: 					       NULL, VG_AR_SYMTAB);
 //:: 
 //:: static struct call_instance *find_call(Addr retaddr, Addr argsp, ThreadId tid)
@@ -611,11 +611,11 @@
 //:: };
 //:: 
 //:: /* A mapping from eip of wrapped function entrypoints to actual wrappers */
 //:: static SkipList wrapped_functions = SKIPLIST_INIT(struct wrapped_function, eip, VG_(cmp_Addr),
 //:: 						  NULL, VG_AR_SYMTAB);
 //:: 
 //:: /* A set of EIPs which are return addresses for wrapped functions */
 //:: static SkipList wrapper_returns = SKIPLIST_INIT(struct wrapper_return, eip, VG_(cmp_Addr),
 //:: 						NULL, VG_AR_SYMTAB);
 //:: 
 //:: /* Wrap function starting at eip */
@@ -518,7 +518,7 @@
 //:: 
 //:: /* List of wrapped call invocations which are currently active */
-//:: static SkipList wrapped_frames = SKIPLIST_INIT(struct call_instance, key, keycmp, 
+//:: static SkipList wrapped_frames = VG_SKIPLIST_INIT(struct call_instance, key, keycmp, 
 //:: 					       NULL, VG_AR_SYMTAB);
 //:: 
@@ -611,11 +611,11 @@
 //:: 
 //:: /* A mapping from eip of wrapped function entrypoints to actual wrappers */
-//:: static SkipList wrapped_functions = SKIPLIST_INIT(struct wrapped_function, eip, VG_(cmp_Addr),
+//:: static SkipList wrapped_functions = VG_SKIPLIST_INIT(struct wrapped_function, eip, VG_(cmp_Addr),
 //:: 						  NULL, VG_AR_SYMTAB);
 //:: 
@@ -611,11 +611,11 @@
 //:: 
 //:: /* A set of EIPs which are return addresses for wrapped functions */
-//:: static SkipList wrapper_returns = SKIPLIST_INIT(struct wrapper_return, eip, VG_(cmp_Addr),
+//:: static SkipList wrapper_returns = VG_SKIPLIST_INIT(struct wrapper_return, eip, VG_(cmp_Addr),
 //:: 						NULL, VG_AR_SYMTAB);
 //:: 